diff --git a/TShockAPI/Configuration/TShockConfig.cs b/TShockAPI/Configuration/TShockConfig.cs
index 14e56cb6..38ed0c46 100644
--- a/TShockAPI/Configuration/TShockConfig.cs
+++ b/TShockAPI/Configuration/TShockConfig.cs
@@ -251,13 +251,13 @@ namespace TShockAPI.Configuration
[Description("Allows groups on the banned item allowed list to spawn banned items even if PreventBannedItemSpawn is set to true.")]
public bool AllowAllowedGroupsToSpawnBannedItems = false;
- /// The number of seconds a player must wait before being respawned. Cannot be longer than normal value now. Use at your own risk.
- [Description("The number of seconds a player must wait before being respawned. Cannot be longer than normal value now. Use at your own risk.")]
- public int RespawnSeconds = 10;
+ /// The number of seconds a player must wait before being respawned. Valid range: 0 (default) to 15 seconds. Use at your own risk.
+ [Description("The number of seconds a player must wait before being respawned. Valid range: 0 (default) to 15 seconds. Use at your own risk.")]
+ public int RespawnSeconds = 0;
- /// The number of seconds a player must wait before being respawned if there is a boss nearby. Cannot be longer than normal value now. Use at your own risk.
- [Description("The number of seconds a player must wait before being respawned if there is a boss nearby. Cannot be longer than normal value now. Use at your own risk.")]
- public int RespawnBossSeconds = 10;
+ /// The number of seconds a player must wait before being respawned if there is a boss nearby. Valid range: 0 (default) to 30 seconds. Use at your own risk.
+ [Description("The number of seconds a player must wait before being respawned if there is a boss nearby. Valid range: 0 (default) to 30 seconds. Use at your own risk.")]
+ public int RespawnBossSeconds = 0;
/// Whether or not to announce boss spawning or invasion starts.
[Description("Whether or not to announce boss spawning or invasion starts.")]